@@ -20,13 +20,13 @@ except ImportError:
 
 DEFAULT_SAMPLE_SIZE_LIMIT = 1073741824  # 1GB in Bytes is verified later by _set_sample_size_limit
 DEFAULT_REDUCED_SAMPLE_SIZE_LIMIT = 104857600  # 100MB in bytes
-DEFAULT_SAMPLING_TYPE = SamplingTypes.FIRST_VALUES
+DEFAULT_SAMPLING_TYPE = SamplingTypes.RANDOM
 
 
 class ExperimentIterableDataset(IterableDataset):
     """
         This dataset is intended to be an Iterable stream from Flight Service.
-        It should iterate over flight logical batches and menages by Connection class
+        It should iterate over flight logical batches and manages by Connection class
         how batches are downloaded and created. It should take into consideration only 2 batches at a time.
         If we have 2 batches already downloaded, it should block further download
         and wait for first batch to be consumed.
@@ -76,11 +76,14 @@ class ExperimentIterableDataset(IterableDataset):
         binary_data: bool = False,
         number_of_batch_rows: int = None,
         stop_after_first_batch: bool = False,
+        total_size_limit=DEFAULT_SAMPLE_SIZE_LIMIT,
+        total_nrows_limit=None,
+        total_percentage_limit=1.0,
         **kwargs,
     ):
         super().__init__()
         self.enable_sampling = enable_sampling
-        self._set_sample_size_limit(sample_size_limit)
+        self.sample_size_limit = sample_size_limit
         self.experiment_metadata = experiment_metadata
         self._wml_client = getattr(connection, "_wml_client", None)
         if self._wml_client is None:
@@ -89,6 +92,9 @@ class ExperimentIterableDataset(IterableDataset):
         self.sampling_type = sampling_type
         self.read_to_file = kwargs.get('read_to_file')
         self.authorized = self._wml_check_authorization()
+        self._set_size_limit(total_size_limit)
+        self.total_nrows_limit = total_nrows_limit
+        self.total_percentage_limit = total_percentage_limit
 
         # Note: convert to dictionary if we have object from WML client
         if not isinstance(connection, dict):
@@ -135,10 +141,10 @@ class ExperimentIterableDataset(IterableDataset):
                 params=self.experiment_metadata,
                 project_id=self.experiment_metadata.get("project_id", getattr(self._wml_client, 'default_project_id', None)),
                 space_id=self.experiment_metadata.get("space_id", getattr(self._wml_client, 'default_space_id', None)),
-                asset_id=None if is_cos_asset else dict_connection.get("location", {}).get("id"), #do not pass asset id for data assets located on COS
+                asset_id=None if is_cos_asset else dict_connection.get("location", {}).get("id"), # do not pass asset id for data assets located on COS
                 connection_id=dict_connection.get("connection", {}).get("id"),
                 data_location=dict_connection,
-                data_size_limit=self.sample_size_limit,
+                data_batch_size_limit=self.sample_size_limit,
                 flight_parameters=kwargs.get("flight_parameters", {}),
                 extra_interaction_properties=kwargs.get("extra_interaction_properties",{}),
                 fallback_to_one_connection=kwargs.get(
@@ -147,7 +153,10 @@ class ExperimentIterableDataset(IterableDataset):
                 number_of_batch_rows=number_of_batch_rows,
                 stop_after_first_batch=stop_after_first_batch,
                 _wml_client=self._wml_client,
-                return_subsampling_stats=kwargs.get("_return_subsampling_stats", False)
+                return_subsampling_stats=kwargs.get("_return_subsampling_stats", False),
+                total_size_limit=self.total_size_limit,
+                total_nrows_limit=self.total_nrows_limit,
+                total_percentage_limit=self.total_percentage_limit,
             )
 
         else:
@@ -171,8 +180,8 @@ class ExperimentIterableDataset(IterableDataset):
         """
         Check if we can authorize with WML.
         If the connection have wml_client initialized use it as an attribute.
-        Otherwise credentials should be provided in the experiment_metadata dictionary.
-        If they the client is properly initialized True will be returned.
+        Otherwise, credentials should be provided in the experiment_metadata dictionary.
+        If the client is properly initialized True will be returned.
         """
         if self._wml_client is not None:
             return True
@@ -194,23 +203,20 @@ class ExperimentIterableDataset(IterableDataset):
         else:
             return False
 
-    def _set_sample_size_limit(self, sample_size_limit):
-        """If non-default value of sample_size_limit was not passed,
+    def _set_size_limit(self, size_limit):
+        """If non-default value of total_size_limit was not passed,
         set Sample Size Limit based on T-Shirt size if code is run on training pod:
         For memory < 32 (T-Shirts: XS,S, M) default is 100MB,
         For memory >= 32 or runs outside pod default is 1GB
         """
-        if sample_size_limit == DEFAULT_SAMPLE_SIZE_LIMIT:
+        if size_limit == DEFAULT_SAMPLE_SIZE_LIMIT:
             size_mem = int(findall(r'[0-9]+', os.environ.get('MEM', '32'))[0])
             if size_mem >= 32:
-                self.sample_size_limit = DEFAULT_SAMPLE_SIZE_LIMIT     # 1GB in bytes
+                self.total_size_limit = DEFAULT_SAMPLE_SIZE_LIMIT     # 1GB in bytes
             else:
-                self.sample_size_limit = DEFAULT_REDUCED_SAMPLE_SIZE_LIMIT      # 100MB in bytes
-
-            if self.enable_sampling is False:
-                self.sample_size_limit = 100*1024*1024*1024 #100 GB, temporary fix 
+                self.total_size_limit = DEFAULT_REDUCED_SAMPLE_SIZE_LIMIT      # 100MB in bytes
         else:
-            self.sample_size_limit = sample_size_limit
+            self.total_size_limit = size_limit
 
     def write(
         self, data: Optional[pd.DataFrame] = None, file_path: Optional[str] = None
@@ -262,6 +268,7 @@ class ExperimentIterableDataset(IterableDataset):
                     return self.connection.read_binary_data(read_to_file=self.read_to_file)
 
                 else:
+                    self.total_size_limit = None
                     return self.connection.iterable_read()
         else:
             return (batch for batch in self.connection)
