@@ -183,6 +183,16 @@ class WMLEngine(BaseEngine):
                 'pipelines'][0]['nodes'][0]['parameters'][
                 'sample_size_limit'] = self._auto_pipelines_parameters.get('sample_size_limit')
 
+        if self._auto_pipelines_parameters.get('sample_rows_limit') is not None:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters'][
+                'sample_rows_limit'] = self._auto_pipelines_parameters.get('sample_rows_limit')
+
+        if self._auto_pipelines_parameters.get('sample_percentage_limit') is not None:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters'][
+                'sample_percentage_limit'] = self._auto_pipelines_parameters.get('sample_percentage_limit')
+
         if self._auto_pipelines_parameters.get('n_parallel_data_connections') is not None:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters'][
