@@ -280,7 +280,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'feature_columns': ts_parameters.get('feature_columns'),
                 'supporting_features_at_forecast': ts_parameters.get('future_exogenous_available'),
                 'pipeline_types': pipeline_types,
-                'retrain_on_holdout': ts_parameters.get('feature_columns', True),
+                'retrain_on_holdout': ts_parameters.get('retrain_on_holdout', True),
             }
 
         else:
