@@ -111,79 +111,8 @@ class Functions(WMLResource):
         if self._client.WSD:
             if "space_uid" in meta_props:
                 raise WMLClientError(u'Invalid input SPACE_UID in meta_props. SPACE_UID not supported for Watson Studio Desktop.')
-        user_content_file = False
-        if type(function) is STR_TYPE:
-            content_path = function
-            user_content_file = True
-        else:
-            try:
-                import inspect
-                import gzip
-                import uuid
-                import re
-                import shutil
-                code = inspect.getsource(function).split('\n')
-                r = re.compile(r"^ *")
-                m = r.search(code[0])
-                intend = m.group(0)
 
-                code = [line.replace(intend, '', 1) for line in code]
-
-                args_spec = inspect.getargspec(function)
-
-                defaults = args_spec.defaults if args_spec.defaults is not None else []
-                args = args_spec.args if args_spec.args is not None else []
-
-                if function.__name__ == 'score':
-                    code = '\n'.join(code)
-                    file_content = code
-                elif len(args) == len(defaults):
-                    for i, d in enumerate(defaults):
-                        if not is_of_python_basic_type(d):
-                            raise UnexpectedType(args[i], 'primitive python type', type(d))
-
-                    new_header = 'def {}({}):'.format(
-                        function.__name__,
-                        ', '.join(
-                            ['{}={}'.format(arg_name, json.dumps(default)) for arg_name, default in zip(args, defaults)]
-                        )
-                    )
-
-                    code[0] = new_header
-                    code = '\n'.join(code)
-                    file_content = """
-{}
-
-score = {}()
-""".format(code, function.__name__)
-                else:
-                    raise WMLClientError("Function passed is not \'score\' function nor generator function. Generator function should have no arguments or all arguments with primitive python default values.")
-
-                tmp_uid = 'tmp_python_function_code_{}'.format(str(uuid.uuid4()).replace('-', '_'))
-                filename = '{}.py'.format(tmp_uid)
-
-                with open(filename, 'w') as f:
-                    f.write(file_content)
-
-                archive_name = '{}.py.gz'.format(tmp_uid)
-
-                with open(filename, 'rb') as f_in:
-                    with gzip.open(archive_name, 'wb') as f_out:
-                        shutil.copyfileobj(f_in, f_out)
-
-                os.remove(filename)
-
-                content_path = archive_name
-            except Exception as e:
-                try:
-                    os.remove(filename)
-                except:
-                    pass
-                try:
-                    os.remove(archive_name)
-                except:
-                    pass
-                raise WMLClientError('Exception during getting function code.', e)
+        content_path, user_content_file, archive_name = self._prepare_function_content(function)
 
         try:
 
@@ -409,81 +338,8 @@ score = {}()
         function = str_type_conv(updated_function)
         import types
         Functions._validate_type(function, u'function', [STR_TYPE, types.FunctionType], True)
-        if type(function) is STR_TYPE:
-            content_path = function
-            user_content_file = True
-        else:
-            try:
-                import inspect
-                import gzip
-                import uuid
-                import re
-                import shutil
-                code = inspect.getsource(function).split('\n')
-                r = re.compile(r"^ *")
-                m = r.search(code[0])
-                intend = m.group(0)
 
-                code = [line.replace(intend, '', 1) for line in code]
-
-                args_spec = inspect.getargspec(function)
-
-                defaults = args_spec.defaults if args_spec.defaults is not None else []
-                args = args_spec.args if args_spec.args is not None else []
-
-                if function.__name__ == 'score':
-                    code = '\n'.join(code)
-                    file_content = code
-                elif len(args) == len(defaults):
-                    for i, d in enumerate(defaults):
-                        if not is_of_python_basic_type(d):
-                            raise UnexpectedType(args[i], 'primitive python type', type(d))
-
-                    new_header = 'def {}({}):'.format(
-                        function.__name__,
-                        ', '.join(
-                            ['{}={}'.format(arg_name, json.dumps(default)) for arg_name, default in zip(args, defaults)]
-                        )
-                    )
-
-                    code[0] = new_header
-                    code = '\n'.join(code)
-
-                    file_content = """
-{}
-
-score = {}()
-""".format(code, function.__name__)
-
-                else:
-                    raise WMLClientError(
-                        "Function passed is not \'score\' function nor generator function. Generator function should have no arguments or all arguments with primitive python default values.")
-
-                tmp_uid = 'tmp_python_function_code_{}'.format(str(uuid.uuid4()).replace('-', '_'))
-                filename = '{}.py'.format(tmp_uid)
-
-                with open(filename, 'w') as f:
-                    f.write(file_content)
-
-                archive_name = '{}.py.gz'.format(tmp_uid)
-
-                with open(filename, 'rb') as f_in:
-                    with gzip.open(archive_name, 'wb') as f_out:
-                        shutil.copyfileobj(f_in, f_out)
-
-                os.remove(filename)
-
-                content_path = archive_name
-            except Exception as e:
-                try:
-                    os.remove(filename)
-                except:
-                    pass
-                try:
-                    os.remove(archive_name)
-                except:
-                    pass
-                raise WMLClientError('Exception during getting function code.', e)
+        content_path, user_content_file, archive_name = self._prepare_function_content(function)
 
         try:
             if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
@@ -1067,6 +923,81 @@ score = {}()
 
                 self._list(function_values, [u'GUID', u'rev', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
 
+    @staticmethod
+    def _prepare_function_content(function):
+        user_content_file = False
+        archive_name = None
 
+        if type(function) is STR_TYPE:
+            content_path = function
+            user_content_file = True
+        else:
+            try:
+                import inspect
+                import gzip
+                import uuid
+                import re
+                import shutil
+                code = inspect.getsource(function).split('\n')
+                r = re.compile(r"^ *")
+                m = r.search(code[0])
+                intend = m.group(0)
 
+                code = [line.replace(intend, '', 1) for line in code]
 
+                args_spec = inspect.getfullargspec(function)
+
+                defaults = args_spec.defaults if args_spec.defaults is not None else []
+                args = args_spec.args if args_spec.args is not None else []
+
+                if function.__name__ == 'score':
+                    code = '\n'.join(code)
+                    file_content = code
+                elif len(args) == len(defaults):
+                    for i, d in enumerate(defaults):
+                        if not is_of_python_basic_type(d):
+                            raise UnexpectedType(args[i], 'primitive python type', type(d))
+
+                    args_pattern = ','.join([fr'\s*{arg}\s*=\s*(.+)\s*' for arg in args])
+                    pattern = fr'^def {function.__name__}\s*\({args_pattern}\)\s*:'
+                    code = '\n'.join(code)
+                    res = re.match(pattern, code)
+
+                    for i in range(len(defaults)-1, -1, -1):
+                        default = defaults[i]
+                        code = code[:res.start(i+1)] + default.__repr__() + code[res.end(i+1):]
+
+                    code += f'\n\nscore = {function.__name__}()'
+
+                    file_content = code
+                else:
+                    raise WMLClientError(
+                        "Function passed is not \'score\' function nor generator function. Generator function should have no arguments or all arguments with primitive python default values.")
+
+                tmp_uid = 'tmp_python_function_code_{}'.format(str(uuid.uuid4()).replace('-', '_'))
+                filename = '{}.py'.format(tmp_uid)
+
+                with open(filename, 'w') as f:
+                    f.write(file_content)
+
+                archive_name = '{}.py.gz'.format(tmp_uid)
+
+                with open(filename, 'rb') as f_in:
+                    with gzip.open(archive_name, 'wb') as f_out:
+                        shutil.copyfileobj(f_in, f_out)
+
+                os.remove(filename)
+
+                content_path = archive_name
+            except Exception as e:
+                try:
+                    os.remove(filename)
+                except:
+                    pass
+                try:
+                    os.remove(archive_name)
+                except:
+                    pass
+                raise WMLClientError('Exception during getting function code.', e)
+
+        return content_path, user_content_file, archive_name
