@@ -528,6 +528,10 @@ class DataConnection(BaseDataConnection):
              binary: Optional[bool] = False,
              read_to_file: Optional[str] = None,
              number_of_batch_rows: Optional[int] = None,
+             sampling_type: Optional[str] = None,
+             sample_size_limit: Optional[int] = None,
+             sample_rows_limit: Optional[int] = None,
+             sample_percentage_limit: Optional[float] = None,
              **kwargs) -> Union['DataFrame', Tuple['DataFrame', 'DataFrame'], bytes]:
         """
         Download dataset stored in remote data storage. Returns batch up to 1GB.
@@ -561,6 +565,23 @@ class DataConnection(BaseDataConnection):
         number_of_batch_rows: int, optional
             Number of rows to read in each batch when reading from flight connection.
 
+        sampling_type: str, optional
+            A sampling strategy how to read the data.
+
+        sample_size_limit: int, optional
+            Upper limit for overall data that should be downloaded in bytes, Default: 1 GB. If more than one of:
+            sample_size_limit, sample_rows_limit, sample_percentage_limit are set, then downloaded data is limited to the lowest threshold.
+
+        sample_rows_limit: int, optional
+            Upper limit for overall data that should be downloaded in number of rows. If more than one of:
+            sample_size_limit, sample_rows_limit, sample_percentage_limit are set, then downloaded data is limited to the lowest threshold.
+
+        sample_percentage_limit: float, optional
+            Upper limit for overall data that should be downloaded in percent of all dataset.
+            This parameter is ignored, when `sampling_type` parameter is set to `first_n_records`.
+            Must be a float number between 0 and 1. If more than one of:
+            sample_size_limit, sample_rows_limit, sample_percentage_limit are set, then downloaded data is limited to the lowest threshold.
+
         Returns
         -------
         pandas.DataFrame contains dataset from remote data storage : Xy_train
@@ -616,10 +637,12 @@ class DataConnection(BaseDataConnection):
             use_flight = False
 
         return_data_as_iterator = kwargs.get('return_data_as_iterator', False)
-        sampling_type = kwargs.get('sampling_type', DEFAULT_SAMPLING_TYPE)
-        sample_size_limit = kwargs.get('sample_size_limit', DEFAULT_SAMPLE_SIZE_LIMIT)
+        sampling_type = sampling_type if sampling_type is not None else DEFAULT_SAMPLING_TYPE
         enable_sampling = kwargs.get('enable_sampling', True)
         read_normal_data_asset_without_flight = kwargs.get('read_normal_data_asset_without_flight', False)
+        total_size_limit = sample_size_limit if sample_size_limit is not None else kwargs.get('total_size_limit', DEFAULT_SAMPLE_SIZE_LIMIT)
+        total_nrows_limit = sample_rows_limit
+        total_percentage_limit = sample_percentage_limit if sample_percentage_limit is not None else 1.0
 
         # Deprecation of excel_sheet as number:
         if isinstance(excel_sheet, int):
@@ -749,10 +772,13 @@ class DataConnection(BaseDataConnection):
                                                                        headers=headers,
                                                                        enable_sampling=enable_sampling,
                                                                        sampling_type=sampling_type,
-                                                                       sample_size_limit=sample_size_limit,
                                                                        number_of_batch_rows=number_of_batch_rows,
                                                                        return_data_as_iterator=return_data_as_iterator,
-                                                                       _return_subsampling_stats=_return_subsampling_stats)
+                                                                       _return_subsampling_stats=_return_subsampling_stats,
+                                                                       total_size_limit=total_size_limit,
+                                                                       total_nrows_limit=total_nrows_limit,
+                                                                       total_percentage_limit=total_percentage_limit
+                                                                       )
                     except (ConnectionError, FlightError, ApiRequestFailure) as download_data_error:
                         # note: try to download normal data asset either directly from cams or from mounted NFS
                         #       to keep backward compatibility
@@ -800,10 +826,12 @@ class DataConnection(BaseDataConnection):
                                                                        headers=headers,
                                                                        enable_sampling=enable_sampling,
                                                                        sampling_type=sampling_type,
-                                                                       sample_size_limit=sample_size_limit,
                                                                        number_of_batch_rows=number_of_batch_rows,
                                                                        return_data_as_iterator=return_data_as_iterator,
-                                                                       _return_subsampling_stats=_return_subsampling_stats)
+                                                                       _return_subsampling_stats=_return_subsampling_stats,
+                                                                       total_size_limit=total_size_limit,
+                                                                       total_nrows_limit=total_nrows_limit,
+                                                                       total_percentage_limit=total_percentage_limit)
 
         elif self.type == DataConnectionTypes.FS:
 
@@ -831,10 +859,12 @@ class DataConnection(BaseDataConnection):
                                                                headers=headers,
                                                                enable_sampling=enable_sampling,
                                                                sampling_type=sampling_type,
-                                                               sample_size_limit=sample_size_limit,
                                                                number_of_batch_rows=number_of_batch_rows,
                                                                return_data_as_iterator=return_data_as_iterator,
-                                                               _return_subsampling_stats=_return_subsampling_stats)
+                                                               _return_subsampling_stats=_return_subsampling_stats,
+                                                               total_size_limit=total_size_limit,
+                                                               total_nrows_limit=total_nrows_limit,
+                                                               total_percentage_limit=total_percentage_limit)
 
             else:  # backward compatibility
                 try:
@@ -871,9 +901,11 @@ class DataConnection(BaseDataConnection):
                                                                    headers=headers,
                                                                    enable_sampling=enable_sampling,
                                                                    sampling_type=sampling_type,
-                                                                   sample_size_limit=sample_size_limit,
                                                                    number_of_batch_rows=number_of_batch_rows,
-                                                                   _return_subsampling_stats=_return_subsampling_stats)
+                                                                   _return_subsampling_stats=_return_subsampling_stats,
+                                                                   total_size_limit=total_size_limit,
+                                                                   total_nrows_limit=total_nrows_limit,
+                                                                   total_percentage_limit=total_percentage_limit)
 
         # create data statistics if data were not downloaded with flight:
         if not isinstance(data, tuple) and _return_subsampling_stats:
