@@ -28,10 +28,14 @@ from ibm_watson_machine_learning.utils.utils import is_lib_installed, prepare_in
 is_lib_installed(lib_name='pyarrow', install=True)
 import pyarrow as pa
 from pyarrow import flight
+from warnings import warn
+
 
 logger = logging.getLogger("automl")
 
 DEFAULT_PARTITIONS_NUM = 4
+DEFAULT_BATCH_SIZE_FLIGHT_COMMAND  = 10000
+DEFAULT_BATCH_SIZE_FLIGHT_COMMAND_BINARY_READ  = 1000
 
 
 class FakeCallback:
@@ -80,8 +84,8 @@ class FlightConnection:
     callback: StatusCallback, required
         Required for sending messages.
 
-    data_size_limit: int, optional
-        Upper limit for overall data that should be downloaded in Bytes, Default: 1GB.
+    data_batch_size_limit: int, optional
+        Upper limit for data in one batch of data that should be downloaded in Bytes, Default: 1GB.
 
     logical_batch_size_limit: int, optional
         Upper limit for logical batch when subsampling is turned on (in Bytes). Default 2GB.
@@ -99,6 +103,20 @@ class FlightConnection:
         Indicates whether return batch data stats: dataset size, no. of batches.
         Applicable only if subsampling is enabled.
         Default False.
+
+    total_size_limit: int, optional
+        Upper limit for overall data that should be downloaded in Bytes, Default: 1GB. IIf more than one of:
+            total_size_limit, total_nrows_limit, total_percentage_limit are set, then data are limited to the lower threshold.
+             If None, then all data are downloaded in batches in iterable_read method.
+
+    total_nrows_limit: int, optional
+        Upper limit for overall data that should be downloaded in number of rows.If more than one of:
+            total_size_limit, total_nrows_limit, total_percentage_limit are set, then data are limited to the lower threshold.
+
+    total_percentage_limit: float, optional
+        Upper limit for overall data that should be downloaded in percent of all dataset.
+            Must be a float number between 0 and 1. If more than one of: total_size_limit, total_nrows_limit,
+             total_percentage_limit are set, then data are limited to the lower threshold.
     """
 
     def __init__(self,
@@ -114,7 +132,7 @@ class FlightConnection:
                  data_location: Optional[dict] = None,
                  enable_subsampling: Optional[bool] = False,
                  callback: Optional['Callback'] = None,
-                 data_size_limit: Optional[int] = 1073741824,  # 1GB in Bytes
+                 data_batch_size_limit: Optional[int] = 1073741824,  # 1GB in Bytes 
                  logical_batch_size_limit: Optional[int] = 1073741824 * 2,  # 2GB in Bytes
                  flight_parameters: dict = None,
                  extra_interaction_properties: dict = None,
@@ -122,6 +140,9 @@ class FlightConnection:
                  number_of_batch_rows: int = None,
                  stop_after_first_batch: bool = False,
                  return_subsampling_stats: bool = False,
+                 total_size_limit=1073741824,  # 1GB in Bytes
+                 total_nrows_limit=None,
+                 total_percentage_limit =1.0,
                  **kwargs
                  ) -> None:
 
@@ -133,10 +154,35 @@ class FlightConnection:
 
         self.number_of_batch_rows = number_of_batch_rows
         self.stop_after_first_batch = stop_after_first_batch
+        
+        # backward compatibility: 
+        if kwargs.get('data_size_limit'):
+            warn("The parameters data_size_limit in FlightConnection is deprecated. Use total_size_limit instead.")
+            self.total_size_limit = kwargs.get('data_size_limit')
 
         # Note: Upper bound limitation for data in memory
-        self.data_size_limit = data_size_limit  # size of normal or subsampled batch in RAM (Bytes)
+        self.data_batch_size_limit = data_batch_size_limit  # size of normal or subsampled batch in RAM (Bytes)
         self.logical_batch_size_limit = logical_batch_size_limit  # size of larger not subsampled batch in RAM (Bytes)
+
+        self.total_size_limit = total_size_limit
+        self.total_nrows_limit = total_nrows_limit
+        self.yielded_nrows = 0
+        if self.total_size_limit:
+            self.data_batch_size_limit = min(self.total_size_limit, self.data_batch_size_limit)
+
+        if self.total_nrows_limit:
+            if self.number_of_batch_rows:
+                self.number_of_batch_rows = min(self.total_nrows_limit, self.number_of_batch_rows)
+            elif self.total_nrows_limit < DEFAULT_BATCH_SIZE_FLIGHT_COMMAND:  # 10000 is default_batch_size in Flight Service command
+                self.number_of_batch_rows = self.total_nrows_limit
+
+        if not isinstance(total_percentage_limit, float) or \
+                (isinstance(total_percentage_limit, float) and (total_percentage_limit<=0.0 or total_percentage_limit>1.0)):
+            raise ValueError("Invalid `total_percentage_limit` parameter's value. "
+                             "The `total_percentage_limit` need to be float between 0.0 and 1.0.")
+        else:
+            self.total_percentage_limit = total_percentage_limit
+
         # --- end note
 
         # callback is used in the backend to send status messages
@@ -440,8 +486,8 @@ class FlightConnection:
                                 self.total_size = self.total_size + row_size * len(data)
 
                                 # note: what to do when we have total size nearly under the limit
-                                if self.total_size <= self.data_size_limit:
-                                    upper_row_limit = (self.data_size_limit - self.total_size) // row_size
+                                if self.total_size <= self.data_batch_size_limit:
+                                    upper_row_limit = (self.data_batch_size_limit - self.total_size) // row_size
                                     data = data.iloc[:upper_row_limit]
                                     self._q_put_nowait((thread_number, data))
                                 # --- end note
@@ -539,11 +585,11 @@ class FlightConnection:
                     break
             else:
                 data_size = sys.getsizeof(data) * self.q.qsize()
-                if data_size >= self.data_size_limit and not self.stop_reading:
+                if data_size >= self.data_batch_size_limit and not self.stop_reading:
                     logger.debug(f"QC {thread_number}: Waiting 3 sec as data queue is too large.")
                     logger.debug(
                         f"QC {thread_number}: Data queue size: {data_size / 1024 / 1024}MB, available memory: "
-                        f"{self.data_size_limit / 1024 / 1024}MB")
+                        f"{self.data_batch_size_limit / 1024 / 1024}MB")
                     with self.read_status_change:
                         self.read_status_change.wait(timeout=3)
                     continue
@@ -627,10 +673,11 @@ class FlightConnection:
         self.callback.status_message("Starting reading training data in batches...")
         if self.enable_subsampling:
             for data in self.read():
+                self.yielded_nrows += len(data)
                 if self.return_subsampling_stats:
                     data_stats = {"data_size": self.downloaded_data_size,
                                   "data_batch_size": sys.getsizeof(data),
-                                  "data_batch_no_rows": len(data),
+                                  "data_batch_nrows": len(data),
                                   "no_batches": self.downloaded_data_size // sys.getsizeof(data)}
                     yield data, data_stats
                 else:
@@ -655,14 +702,20 @@ class FlightConnection:
             logger.debug(f"IR: Logical batch number {n} received.")
             logger.debug(f"IR: Passing batch to upper layer.")
             self._check_for_breaking_exceptions()
+            self.yielded_nrows += len(batch)
+
+            if len(batch) == 0:
+                break
+
             if self.return_subsampling_stats:
                 yield batch, {"data_batch_size": sys.getsizeof(batch),
-                              "data_batch_no_rows": len(batch)}
+                              "data_batch_nrows": len(batch)}
             else:
                 yield batch
 
             logger.debug(f"IR: We have control back, creating next batch...")
-            if n == 0 and self.stop_after_first_batch:
+            if (n == 0 and self.stop_after_first_batch) or (
+                    self.total_nrows_limit and self.total_nrows_limit - self.yielded_nrows <= 0):
                 self._set_stop_reading(True)
                 break
 
@@ -729,11 +782,17 @@ class FlightConnection:
             self._check_for_breaking_exceptions()
 
             if self.enable_subsampling:
+                if self.row_size > 0:
+                    self.subsampled_data = self._sample_data_to_percentage(self.total_percentage_limit,
+                                                                           self.subsampled_data,
+                                                                           self.downloaded_data_size // self.row_size)
                 self.subsampled_data = self._process_data(self.subsampled_data)
+                self.yielded_nrows += len(self.subsampled_data)
                 yield self.subsampled_data
 
             else:
                 self.data = self._process_data(self.data)
+                self.yielded_nrows += len(self.data)
                 yield self.data
 
         except ValueError as e:
@@ -759,10 +818,12 @@ class FlightConnection:
             try:
                 if self.enable_subsampling:
                     self.subsampled_data = self._process_data(self.subsampled_data)
+                    self.yielded_nrows += len(self.subsampled_data)
                     yield self.subsampled_data
 
                 else:
                     self.data = self._process_data(self.data)
+                    self.yielded_nrows += len(self.data)
                     yield self.data
 
             except ValueError:
@@ -778,7 +839,21 @@ class FlightConnection:
 
             if self.row_size != 0:
                 if _type == 'data':
-                    return self.data_size_limit // self.row_size
+                    max_rows = self.data_batch_size_limit // self.row_size
+
+                    if self.total_size_limit is not None:
+                        # Note: convert total_size_limit to total_nrows_limit, later only total_nrows_limit will be used.
+                        max_rows_total = self.total_size_limit // self.row_size
+                        if self.total_nrows_limit:
+                            if max_rows_total < self.total_nrows_limit:
+                                self.total_nrows_limit = max_rows_total
+                        else:
+                            self.total_size_limit = max_rows_total
+
+                    if self.total_nrows_limit and self.total_nrows_limit < max_rows:
+                        return self.total_nrows_limit
+                    else:
+                        return max_rows
 
                 else:
                     return self.logical_batch_size_limit // self.row_size
@@ -905,6 +980,7 @@ class FlightConnection:
         logical_batch = []
         mini_batch_counter = 0
         threads_finished = 0
+        data = None
 
         while True:
             try:
@@ -954,7 +1030,14 @@ class FlightConnection:
                 yield self._process_data(data)
 
                 logical_batch = [not_used_data]
-                max_rows = self._get_max_rows(_type=_type) - len(logical_batch[-1])
+                if self.total_nrows_limit:
+                    max_rows = min(self._get_max_rows(_type=_type) - len(logical_batch[-1]),
+                                   self.total_nrows_limit - self.yielded_nrows)
+                else:
+                    max_rows = self._get_max_rows(_type=_type) - len(logical_batch[-1])
+
+                if max_rows < 0:  # finish if limit has been reached
+                    break
 
     def _select_source_command(self, infer_schema: bool = True) -> List[str]:
         """Based on a data source type, select appropriate commands for flight service configuration."""
@@ -970,14 +1053,14 @@ class FlightConnection:
             # limitation for number of rows passed within one mini batch
             # from flight service (can be between 100 and 10000)
             # need to test performance with big data
-            default_batch_size = 10000
+            default_batch_size = DEFAULT_BATCH_SIZE_FLIGHT_COMMAND
             # when reading binary batches, default row is one value of 32k.
             # If we keep a large default batch size like 10k, we end up with
             # batches of 300MB being read and kept in memory as 10k chunks
             # of 32k. This clutters the memory and is more work for GC.
             # Defaulting to 1000 when reading binary to decrease footprint.
             if self.read_binary:
-                default_batch_size = 1000
+                default_batch_size = DEFAULT_BATCH_SIZE_FLIGHT_COMMAND_BINARY_READ
             # when dataset is small we received empty dfs, it is ok (4 is optimum for larger than 1 GB)
             command = {
                 "num_partitions": self.max_flight_batch_number if self.max_flight_batch_number is not None else DEFAULT_PARTITIONS_NUM,
@@ -1181,3 +1264,38 @@ class FlightConnection:
             return self.truncate_sampling
         else:
             raise InvalidSamplingType(self.sampling_type, self.learning_type)
+
+
+    def _sample_data_to_percentage(self, percentage, data, full_data_nrows):
+        if self.enable_subsampling:
+            if percentage < 1.0 and percentage>0.0:
+                nrows = int(percentage * full_data_nrows)
+                logger.debug(f"Running sampling to prercentage of data: "
+                             f"{percentage} from {full_data_nrows} rows gives {nrows} of data rows")
+                if len(data) < nrows:
+                    return data   # no sampling needed
+
+                if self.sampling_type == SamplingTypes.RANDOM:
+                    data = data.sample(n=nrows, random_state=0, axis=0)
+                elif self.sampling_type == SamplingTypes.STRATIFIED:
+                    from sklearn.model_selection import StratifiedShuffleSplit
+                    sss = StratifiedShuffleSplit(n_splits=1, train_size=nrows, random_state=0)
+
+                    # start sampling
+                    for train_index, _ in sss.split(data.drop([self.label], axis=1).values, data[self.label].values):
+                        data = data.iloc[train_index]
+
+                elif self.sampling_type == SamplingTypes.LAST_VALUES:
+                    timestamp_column = self.params.get('timestamp_column') or self.params.get('timestamp_column_name')
+                    if timestamp_column is not None:
+                        data = data.sort_values(timestamp_column)
+                    data = data.tail(nrows)
+                else:
+                    raise NotImplementedError(f"Sampling type: {self.sampling_type} does not supports additional sampling to percentage of data.")
+                return data
+            elif percentage == 1.0:
+                return data
+            else:
+                raise ValueError('The `percentage` need to be float between 0.0 and 1.0.')
+        else:
+            return data
