@@ -362,11 +362,7 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
         )
 
         # Update Raw Prediction
-        if self.loss != 'categorical_crossentropy':
-            self.raw_predictions[k] += \
-                self.loss_.inverse_link_function(predict(self.X_train))
-        else:
-            self.raw_predictions[k] += predict(self.X_train)
+        self.raw_predictions[k, :] += predict(self.X_train)
 
     def data_val_enc(self):
         """
