@@ -655,7 +655,6 @@ class ModelCollection:
             dataref_list = artifact.meta.prop(MetaNames.TRAINING_DATA_REFERENCES)
             training_data_list = []
             if isinstance(dataref_list, list):
-                i=1
                 for iter1 in dataref_list:
                     training_ref_obj = iter1
                     type_ = training_ref_obj.get('type', None)
@@ -667,13 +666,15 @@ class ModelCollection:
                         training_schema["id"] = "1"
                         schema = training_schema
 
-                    training_ref = {"id": training_ref_obj.get('id', i),
+                    training_ref = {
                                     "type": type_,
                                     "connection": connection,
                                     "location": location,
                                     "schema": schema
                                     }
-                    i = i + 1
+
+                    if training_ref_obj.get('id'):
+                        training_ref['id'] = training_ref_obj.get('id')
 
                     training_data_list.append(training_ref)
         else:
