@@ -149,7 +149,7 @@ class PkgExtn(WMLResource):
 
                     response = requests.put(
                         url,
-                        files={"file": chunk}
+                        files={"file": (file, chunk, 'application/octet-stream')}
                     )
 
                 return response
