@@ -483,4 +483,7 @@ class RemoteTrainingSystem(WMLResource):
         if "hyperparams" in party_metadata:
             party_config["hyperparams"] = party_metadata[self._client.remote_training_systems.ConfigurationMetaNames.HYPERPARAMS]
 
+        if "model" in party_metadata:
+            party_config["model"] = party_metadata[self._client.remote_training_systems.ConfigurationMetaNames.MODEL] 
+
         return Party(client=self._client, config_dict=party_config)
