@@ -14,7 +14,7 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
+from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos, modify_details_for_script_and_shiny
 from ibm_watson_machine_learning.metanames import ScriptMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure, ForbiddenActionForGitBasedProject
@@ -61,6 +61,7 @@ class Script(WMLResource):
             if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
                 return response
             else:
+                response = modify_details_for_script_and_shiny(response)
                 final_response = {
                     "metadata": response[u'metadata'],
                 }
