@@ -60,7 +60,8 @@ __all__ = [
     'ImputationListNotSupported',
     'MissingEstimatorForExistingBatchedEstimator',
     'FutureExogenousFeaturesNotSupported',
-    'NoAvailableNotebookLocation'
+    'NoAvailableNotebookLocation',
+    "ContainerTypeNotSupported"
 ]
 
 #  (C) Copyright IBM Corp. 2021.
@@ -429,4 +430,10 @@ class NoAvailableNotebookLocation(WMLClientError, ValueError):
     def __init__(self, pipeline_name):
         WMLClientError.__init__(self, f"Unable to find notebook location in training details for {pipeline_name}. " +
                                 "Possible causes: pipeline failure or pipeline not classified as winner in " +
-                                "forecasting scenario.")
\ No newline at end of file
+                                "forecasting scenario.")
+
+
+class ContainerTypeNotSupported(WMLClientError, ValueError):
+    def __init__(self):
+        WMLClientError.__init__(self, f"The container data connection type is not supported for CP4D environment."
+                                      f" Supported types are: data asset and connection asset. ")
\ No newline at end of file
